@@ -63,6 +63,7 @@ class Sentence(abcsent.Sentence):
 
     def named_entities(self) -> List[Dict[str, Union[str, int]]]:
         """Returns named entities in the sentence."""
+
         named_entities = self.nlp.named_entities(self.text_)
 
         for ne_ in named_entities:
@@ -70,6 +71,19 @@ class Sentence(abcsent.Sentence):
             ne_['sent_pos_end_'] = ne_.pop('end')
             ne_['text_'] = ne_.pop('text')
 
+        # If n-grams are added in the text we don't want to find a named entities twice:
+        # Examples: Donald Trump __Donald_Trump__ made his speech in New York __New_York__
+        # we don't want ngrams_entities: [{'start': 0, 'end': 1, 'text': 'Donald Trump'}, {'start': 2, 'end': 2, 'text': 'Donald Trump'}, {'start': 7, 'end': 8, 'text': 'New York'}, {'start': 9, 'end': 9, 'text': 'New York'}]
+        # we want ngram_entities_: [{'start': 0, 'end': 1, 'text': 'Donald Trump'}, {'start': 7, 'end': 8, 'text': 'New York'}]
+        if self.nlp.__ngrams_replaced__ == False:
+            named_entities_ = list()
+            for ne_ in named_entities:
+                if ne_['sent_pos_start_'] == ne_['sent_pos_end_'] and len(ne_['text_'].split()) > 1:
+                    continue
+                else:
+                    named_entities_.append(ne_)
+            return named_entities_
+
         return named_entities
 
     def next_para_pos(self) -> int:
